# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
# Copyright 2023 The HuggingFace Team. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# flake8: noqa
from ...utils import is_paddlenlp_available
from .pipeline_latent_diffusion_superresolution import LDMSuperResolutionPipeline

if is_paddlenlp_available():
    from .pipeline_latent_diffusion import (
        LDMBertConfig,
        LDMBertModel,
        LDMTextToImagePipeline, )
